##  Filling Mandatory Attributes
When mandatory attributes are defined by the admin, they appear listed on the right-side panel of the fact sheet until the quality seal is approved. Checkboxes next to them indicate whether they are filled or not. You can use the list to conveniently navigate to the respective fields and provide the needed input.
![Filling Mandatory Attributes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b37d67a44101491d4cc3dab7cae35_LowRes.gif)
Filling Mandatory Attributes
For mandatory relations, you have to specify at least one relation in the field. Setting the relation empty by selecting Leave empty also counts as a filled relation.
![Leaving a Mandatory Relation Empty on Purpose](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741b2717a44101490fbf523a9b9124a_LowRes.png)
Leaving a Mandatory Relation Empty on Purpose
Similarly, you have to assign at least one tag if a tag group is defined as mandatory.
The mandatory subscriptions, if defined, are also listed on the right-side panel of the fact sheet. Click on the item to open the subscription overlay and add the appropriate person as a subscriber. To learn more about subscriptions, see [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
